@@ -1,9 +1,11 @@
 .Integrate <- function(...)
 {
   op <- getOption("show.error.messages")
+  on.exit( options(show.error.messages=op) )
   options(show.error.messages=FALSE)
+  
   res <- try((integrate(...)));
-  options(show.error.messages=op)
+
   if (inherits(res, "try-error"))
   {
     return(-Inf)
