@@ -1,4 +1,4 @@
-spectR_t<-function(phylo,dat,draw=F){
+spectR_t<-function(phylo,dat,draw=FALSE){
 	if (length(phylo$tip.label)!=length(dat)) 
         stop("dat do not match phylo")
        
@@ -14,9 +14,9 @@ spectR_t<-function(phylo,dat,draw=F){
 	x<-eigen(
 		graph.laplacian(
 			graph.adjacency(difmat,
-			weighted=T,mode='undirected'),
-		normalized=T),
-	only.values=F)
+			weighted=TRUE,mode='undirected'),
+		normalized=TRUE),
+	only.values=FALSE)
 	x<-subset(x$values,x$values>0.1)
 	
 		l=length(x)
@@ -33,13 +33,16 @@ spectR_t<-function(phylo,dat,draw=F){
 		fragmenter=(sum((x-mean(x))^3)/l)/(sum((x-mean(x))^2)/l)^(3/2)
 		res<-list(eigenvalues=x,splitter=splitter,tracer=tracer,fragmenter=fragmenter)
 		#plot spectral density profile
-		if(draw==T){
+		if(draw==TRUE){
+			oldpar<-par(no.readonly=TRUE)
+			on.exit(par(oldpar))
 		par(mar=c(4,5,1,1))
 		plot(d$x,dsc,type='l',
 			xlab=expression(''[n]*lambda),
 			ylab=expression(paste('f(x)/',integral(f(y)*dy)),sep=''))
 			polygon(d$x,dsc,col=colors(1)[runif(1,1,500)])	
-		return(res)
+
+			return(res)
 		}
 	else{return(res)}
 	}
